# from AESLF.aeslf.fluency_score_interface import LanguageModelFluencyScoreInterface
#
# # https://github.com/opencog/link-grammar/blob/master/bindings/python/linkgrammar.py
# # https://github.com/opencog/link-grammar/tree/master/docker/docker-python
# # Ou en service Java https://github.com/opencog/link-grammar/blob/master/docker/docker-parser/Dockerfile
#
#
# class LinkGrammar(LanguageModelFluencyScoreInterface):
#     def compute_score(self, sentence: str) -> float:
#         parsed_sentence = ""
